Please see [https://docs.mlcommons.org/cm4mlops/scripts/Compiler-automation/get-compiler-rust](https://docs.mlcommons.org/cm4mlops/scripts/Compiler-automation/get-compiler-rust) for the documentation of this CM script.
